@@ -67,7 +67,7 @@ pub(crate) fn replace_derive_with_manual_impl(
         items_locator::AssocItemSearch::Exclude,
         Some(items_locator::DEFAULT_QUERY_SEARCH_LIMIT.inner()),
     )
-    .filter_map(|item| match ModuleDef::from(item.as_module_def_id()?) {
+    .filter_map(|item| match item.as_module_def()? {
         ModuleDef::Trait(trait_) => Some(trait_),
         _ => None,
     })
